# Doctorr

<p align="center">
  <img src="https://github.com/nibbleai/doctorr/blob/master/doctorr.png?raw=true" alt="A cute python doctor with a book" style="width: 350px;">
</p>

Next level flexible autodocumentation tooling for python pros.
